..
    Copyright 2019 - Swiss Data Science Center (SDSC)
    A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
    Eidgenössische Technische Hochschule Zürich (ETHZ).

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

.. _glossary:

Glossary
========

.. glossary::

   inputs
      Files and/or directories which are required for running tools.

   outputs
      Files and/or directories which are created or modified during
      an execution of a tool.

   tool
      A description of a standalone, non-interactive program which can be
      invoked on some inputs, produces outputs, and then terminates
      [#cwl-tool]_.


.. [#cwl-tool] https://www.commonwl.org/v1.0/CommandLineTool.html
